/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005, 2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/
package com.ibm.team.build.client;

import com.ibm.team.build.internal.common.helper.ValidationHelper;
import com.ibm.team.repository.client.ITeamRepository;

/**
 * Client side factory for getting build client libraries.
 * 
 * @since 0.5
 */
public class ClientFactory {
    
    static {
        
        // Instantiate an instance to get around code coverage limitation that
        // it can't currently exclude intentionally private constructors
        new ClientFactory();
    }

    /**
     * Private default constructor to prevent instances.
     */
    private ClientFactory() {
        // Don't want any instances
    }

    /**
     * Retrieves the team build client library.
     * 
     * @param teamRepository
     *            the team repository
     * @return the team build client library
     * @throws IllegalArgumentException
     *             if the <code>teamRepository</code> is <code>null</code>
     */
    public static ITeamBuildClient getTeamBuildClient(ITeamRepository teamRepository) throws IllegalArgumentException {
        ValidationHelper.validateNotNull("teamRepository", teamRepository); //$NON-NLS-1$
        return (ITeamBuildClient) teamRepository.getClientLibrary(ITeamBuildClient.class);
    }

    /**
     * Retrieves the team build request client library.
     * 
     * @param teamRepository
     *            the team repository
     * @return the team build client library
     * @throws IllegalArgumentException
     *             if the <code>teamRepository</code> is <code>null</code>
     */
    public static ITeamBuildRequestClient getTeamBuildRequestClient(ITeamRepository teamRepository)
            throws IllegalArgumentException {
        ValidationHelper.validateNotNull("teamRepository", teamRepository); //$NON-NLS-1$

        return (ITeamBuildRequestClient) teamRepository.getClientLibrary(ITeamBuildRequestClient.class);
    }

}
