/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2014. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/

package com.ibm.team.build.internal.client;

import org.eclipse.core.runtime.IProgressMonitor;

import com.ibm.team.build.internal.common.model.dto.IIncomingChangesResponse;
import com.ibm.team.repository.common.IItemHandle;
import com.ibm.team.repository.common.TeamRepositoryException;

/**
 * Provides access to the repository service that can perform SCM related tasks
 * for a build.
 * @since 0.10.0 (RTC 5.0)
 */
public interface ITeamBuildScmClient {
    /**
     * Determine if there are incoming changes that would trigger a build.
     * The changes could be change sets that would be accepted/discarded or components
     * added/removed. The build workspace's flow targets are consulted (including scoped flows)
     * in the determination if there are changes (equivalent to the processing done in SourceControlUtility).
     * @param itemHandle The handle of the build workspace or the build definition whose SCM participant identifies
     * the build workspace. Not <code>null</code>
     * @param monitor Monitor to allow for cancellation of the request
     * @return Structure indicating the result of the check for incoming changes.
     * @throws TeamRepositoryException Thrown if anything goes wrong.
     */
    public IIncomingChangesResponse incomingChanges(IItemHandle itemHandle, IProgressMonitor monitor) throws TeamRepositoryException;

}
