/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2014. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/

package com.ibm.team.build.internal.client;

import org.eclipse.core.runtime.IProgressMonitor;

import com.ibm.team.build.internal.common.ITeamBuildScmService;
import com.ibm.team.build.internal.common.model.dto.IIncomingChangesResponse;
import com.ibm.team.repository.client.util.IClientLibraryContext;
import com.ibm.team.repository.client.util.ThreadCheck;
import com.ibm.team.repository.common.IItemHandle;
import com.ibm.team.repository.common.TeamRepositoryException;
import com.ibm.team.scm.common.IRepositoryProgressMonitor;

/**
 * Provides client side access to {@link ITeamBuildScmService}
 */
public class TeamBuildScmClient implements ITeamBuildScmClient {

    private IClientLibraryContext clientLibraryContext;

    /**
     * @param context The context for accessing the {@link ITeamBuildScmService} service
     */
    public TeamBuildScmClient(IClientLibraryContext context) {
        // validate arguments
        if (context == null) {
            throw new IllegalArgumentException();
        }

        this.clientLibraryContext = context;
    }

    /**
     * @return The remote service for the SCM related build tasks
     * @throws TeamRepositoryException Thrown if anything goes wrong
     */
    private ITeamBuildScmService getScmBuildParticipantService()
            throws TeamRepositoryException {
        return (ITeamBuildScmService) clientLibraryContext
                .getServiceInterface(ITeamBuildScmService.class);
    }

    @Override
    public IIncomingChangesResponse incomingChanges(IItemHandle itemHandle, IProgressMonitor monitor) throws TeamRepositoryException {

        ThreadCheck.checkLongOpsAllowed();
        IRepositoryProgressMonitor progressMonitor = IRepositoryProgressMonitor.ITEM_FACTORY.createItem(monitor);

        ITeamBuildScmService service = getScmBuildParticipantService();
        return service.incomingChanges(itemHandle, progressMonitor);
    }
}
